@@ -1140,8 +1140,8 @@ test_that("fit", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- logistic6_new(x, y, w, c(0, 1, 1, 1, 1, 1), max_iter, NULL, NULL)
@@ -1155,8 +1155,8 @@ test_that("fit", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1210,8 +1210,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1229,8 +1229,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1248,8 +1248,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1303,8 +1303,8 @@ test_that("fit_constrained: equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1322,8 +1322,8 @@ test_that("fit_constrained: equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1341,8 +1341,8 @@ test_that("fit_constrained: equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1396,8 +1396,8 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1415,8 +1415,8 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1434,8 +1434,8 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1489,8 +1489,8 @@ test_that("fit (weighted)", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- logistic6_new(
@@ -1506,8 +1506,8 @@ test_that("fit (weighted)", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1561,8 +1561,8 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1580,8 +1580,8 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1599,8 +1599,8 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1654,8 +1654,8 @@ test_that("fit_constrained (weighted): equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1673,8 +1673,8 @@ test_that("fit_constrained (weighted): equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1692,8 +1692,8 @@ test_that("fit_constrained (weighted): equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1747,8 +1747,8 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1766,8 +1766,8 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1785,8 +1785,8 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
